@@ -32,7 +32,7 @@ use crate::{apply_method_physical_integer, POOL};
 //
 // if the windows don't overlap, we should not use these kernels as they are single threaded, so
 // we miss out on easy parallelization.
-fn use_rolling_kernels(groups: &GroupsSlice, chunks: &[ArrayRef]) -> bool {
+pub fn _use_rolling_kernels(groups: &GroupsSlice, chunks: &[ArrayRef]) -> bool {
     match groups.len() {
         0 | 1 => false,
         _ => {
@@ -45,7 +45,7 @@ fn use_rolling_kernels(groups: &GroupsSlice, chunks: &[ArrayRef]) -> bool {
 }
 
 // Use an aggregation window that maintains the state
-pub(super) fn rolling_apply_agg_window_nulls<'a, Agg, T, O>(
+pub fn _rolling_apply_agg_window_nulls<'a, Agg, T, O>(
     values: &'a [T],
     validity: &'a Bitmap,
     offsets: O,
@@ -64,14 +64,16 @@ where
         ));
     }
 
-    let len = values.len();
+    // This iterators length can be trusted
+    // these represent the number of groups in the groupby operation
+    let output_len = offsets.size_hint().0;
     // start with a dummy index, will be overwritten on first iteration.
     // Safety:
     // we are in bounds
     let mut agg_window = unsafe { Agg::new(values, validity, 0, 0) };
 
-    let mut validity = MutableBitmap::with_capacity(len);
-    validity.extend_constant(len, true);
+    let mut validity = MutableBitmap::with_capacity(output_len);
+    validity.extend_constant(output_len, true);
 
     let out = offsets
         .enumerate()
@@ -106,10 +108,7 @@ where
 }
 
 // Use an aggregation window that maintains the state
-pub(crate) fn rolling_apply_agg_window_no_nulls<'a, Agg, T, O>(
-    values: &'a [T],
-    offsets: O,
-) -> ArrayRef
+pub fn _rolling_apply_agg_window_no_nulls<'a, Agg, T, O>(values: &'a [T], offsets: O) -> ArrayRef
 where
     // items (offset, len) -> so offsets are offset, offset + len
     Agg: RollingAggWindowNoNulls<'a, T>,
@@ -144,7 +143,7 @@ where
     Box::new(out)
 }
 
-fn slice_from_offsets<T>(ca: &ChunkedArray<T>, first: IdxSize, len: IdxSize) -> ChunkedArray<T>
+pub fn _slice_from_offsets<T>(ca: &ChunkedArray<T>, first: IdxSize, len: IdxSize) -> ChunkedArray<T>
 where
     T: PolarsDataType,
 {
@@ -152,7 +151,7 @@ where
 }
 
 // helper that combines the groups into a parallel iterator over `(first, all): (u32, &Vec<u32>)`
-fn agg_helper_idx<T, F>(groups: &GroupsIdx, f: F) -> Series
+pub fn _agg_helper_idx<T, F>(groups: &GroupsIdx, f: F) -> Series
 where
     F: Fn((IdxSize, &Vec<IdxSize>)) -> Option<T::Native> + Send + Sync,
     T: PolarsNumericType,
@@ -174,7 +173,7 @@ where
     ca.into_series()
 }
 
-fn agg_helper_slice<T, F>(groups: &[[IdxSize; 2]], f: F) -> Series
+pub fn _agg_helper_slice<T, F>(groups: &[[IdxSize; 2]], f: F) -> Series
 where
     F: Fn([IdxSize; 2]) -> Option<T::Native> + Send + Sync,
     T: PolarsNumericType,
@@ -226,7 +225,7 @@ impl Series {
                 }
             }),
             GroupsProxy::Slice { groups, .. } => {
-                agg_helper_slice::<IdxType, _>(groups, |[first, len]| {
+                _agg_helper_slice::<IdxType, _>(groups, |[first, len]| {
                     debug_assert!(len <= self.len() as IdxSize);
                     if len == 0 {
                         None
@@ -288,7 +287,7 @@ impl Series {
                 }
             }),
             GroupsProxy::Slice { groups, .. } => {
-                agg_helper_slice::<IdxType, _>(groups, |[first, len]| {
+                _agg_helper_slice::<IdxType, _>(groups, |[first, len]| {
                     debug_assert!(len <= self.len() as IdxSize);
                     if len == 0 {
                         None
@@ -301,6 +300,62 @@ impl Series {
         }
     }
 
+    #[doc(hidden)]
+    pub unsafe fn agg_median(&self, groups: &GroupsProxy) -> Series {
+        use DataType::*;
+
+        match self.dtype() {
+            Float32 => SeriesWrap(self.f32().unwrap().clone()).agg_median(groups),
+            Float64 => SeriesWrap(self.f64().unwrap().clone()).agg_median(groups),
+            dt if dt.is_numeric() || dt.is_temporal() => {
+                let ca = self.to_physical_repr();
+                let physical_type = ca.dtype();
+                let s = apply_method_physical_integer!(ca, agg_median, groups);
+                if dt.is_logical() {
+                    // back to physical and then
+                    // back to logical type
+                    s.cast(physical_type).unwrap().cast(dt).unwrap()
+                } else {
+                    s
+                }
+            }
+            _ => Series::full_null("", groups.len(), self.dtype()),
+        }
+    }
+
+    #[doc(hidden)]
+    pub unsafe fn agg_quantile(
+        &self,
+        groups: &GroupsProxy,
+        quantile: f64,
+        interpol: QuantileInterpolOptions,
+    ) -> Series {
+        use DataType::*;
+
+        match self.dtype() {
+            Float32 => {
+                SeriesWrap(self.f32().unwrap().clone()).agg_quantile(groups, quantile, interpol)
+            }
+            Float64 => {
+                SeriesWrap(self.f64().unwrap().clone()).agg_quantile(groups, quantile, interpol)
+            }
+            dt if dt.is_numeric() || dt.is_temporal() => {
+                let ca = self.to_physical_repr();
+                let physical_type = ca.dtype();
+                let s =
+                    apply_method_physical_integer!(ca, agg_quantile, groups, quantile, interpol);
+                if dt.is_logical() {
+                    // back to physical and then
+                    // back to logical type
+                    s.cast(physical_type).unwrap().cast(dt).unwrap()
+                } else {
+                    s
+                }
+            }
+            _ => Series::full_null("", groups.len(), self.dtype()),
+        }
+    }
+
     #[doc(hidden)]
     pub unsafe fn agg_mean(&self, groups: &GroupsProxy) -> Series {
         use DataType::*;
@@ -350,6 +405,24 @@ impl Series {
     }
 }
 
+#[inline(always)]
+fn take_min<T: PartialOrd>(a: T, b: T) -> T {
+    if a < b {
+        a
+    } else {
+        b
+    }
+}
+
+#[inline(always)]
+fn take_max<T: PartialOrd>(a: T, b: T) -> T {
+    if a > b {
+        a
+    } else {
+        b
+    }
+}
+
 impl<T> ChunkedArray<T>
 where
     T: PolarsNumericType + Sync,
@@ -371,9 +444,8 @@ where
             }
             _ => {}
         }
-
         match groups {
-            GroupsProxy::Idx(groups) => agg_helper_idx::<T, _>(groups, |(first, idx)| {
+            GroupsProxy::Idx(groups) => _agg_helper_idx::<T, _>(groups, |(first, idx)| {
                 debug_assert!(idx.len() <= self.len());
                 if idx.is_empty() {
                     None
@@ -384,13 +456,13 @@ where
                         (false, 1) => Some(take_agg_no_null_primitive_iter_unchecked(
                             self.downcast_iter().next().unwrap(),
                             idx.iter().map(|i| *i as usize),
-                            |a, b| if a < b { a } else { b },
+                            take_min,
                             T::Native::max_value(),
                         )),
                         (_, 1) => take_agg_primitive_iter_unchecked::<T::Native, _, _>(
                             self.downcast_iter().next().unwrap(),
                             idx.iter().map(|i| *i as usize),
-                            |a, b| if a < b { a } else { b },
+                            take_min,
                             T::Native::max_value(),
                             idx.len() as IdxSize,
                         ),
@@ -405,16 +477,16 @@ where
                 groups: groups_slice,
                 ..
             } => {
-                if use_rolling_kernels(groups_slice, self.chunks()) {
+                if _use_rolling_kernels(groups_slice, self.chunks()) {
                     let arr = self.downcast_iter().next().unwrap();
                     let values = arr.values().as_slice();
                     let offset_iter = groups_slice.iter().map(|[first, len]| (*first, *len));
                     let arr = match arr.validity() {
-                        None => rolling_apply_agg_window_no_nulls::<MinWindow<_>, _, _>(
+                        None => _rolling_apply_agg_window_no_nulls::<MinWindow<_>, _, _>(
                             values,
                             offset_iter,
                         ),
-                        Some(validity) => rolling_apply_agg_window_nulls::<
+                        Some(validity) => _rolling_apply_agg_window_nulls::<
                             rolling::nulls::MinWindow<_>,
                             _,
                             _,
@@ -422,13 +494,13 @@ where
                     };
                     Self::from_chunks("", vec![arr]).into_series()
                 } else {
-                    agg_helper_slice::<T, _>(groups_slice, |[first, len]| {
+                    _agg_helper_slice::<T, _>(groups_slice, |[first, len]| {
                         debug_assert!(len <= self.len() as IdxSize);
                         match len {
                             0 => None,
                             1 => self.get(first as usize),
                             _ => {
-                                let arr_group = slice_from_offsets(self, first, len);
+                                let arr_group = _slice_from_offsets(self, first, len);
                                 arr_group.min()
                             }
                         }
@@ -449,8 +521,9 @@ where
             }
             _ => {}
         }
+
         match groups {
-            GroupsProxy::Idx(groups) => agg_helper_idx::<T, _>(groups, |(first, idx)| {
+            GroupsProxy::Idx(groups) => _agg_helper_idx::<T, _>(groups, |(first, idx)| {
                 debug_assert!(idx.len() <= self.len());
                 if idx.is_empty() {
                     None
@@ -462,14 +535,14 @@ where
                             take_agg_no_null_primitive_iter_unchecked(
                                 self.downcast_iter().next().unwrap(),
                                 idx.iter().map(|i| *i as usize),
-                                |a, b| if a > b { a } else { b },
+                                take_max,
                                 T::Native::min_value(),
                             )
                         }),
                         (_, 1) => take_agg_primitive_iter_unchecked::<T::Native, _, _>(
                             self.downcast_iter().next().unwrap(),
                             idx.iter().map(|i| *i as usize),
-                            |a, b| if a > b { a } else { b },
+                            take_max,
                             T::Native::min_value(),
                             idx.len() as IdxSize,
                         ),
@@ -484,16 +557,16 @@ where
                 groups: groups_slice,
                 ..
             } => {
-                if use_rolling_kernels(groups_slice, self.chunks()) {
+                if _use_rolling_kernels(groups_slice, self.chunks()) {
                     let arr = self.downcast_iter().next().unwrap();
                     let values = arr.values().as_slice();
                     let offset_iter = groups_slice.iter().map(|[first, len]| (*first, *len));
                     let arr = match arr.validity() {
-                        None => rolling_apply_agg_window_no_nulls::<MaxWindow<_>, _, _>(
+                        None => _rolling_apply_agg_window_no_nulls::<MaxWindow<_>, _, _>(
                             values,
                             offset_iter,
                         ),
-                        Some(validity) => rolling_apply_agg_window_nulls::<
+                        Some(validity) => _rolling_apply_agg_window_nulls::<
                             rolling::nulls::MaxWindow<_>,
                             _,
                             _,
@@ -501,13 +574,13 @@ where
                     };
                     Self::from_chunks("", vec![arr]).into_series()
                 } else {
-                    agg_helper_slice::<T, _>(groups_slice, |[first, len]| {
+                    _agg_helper_slice::<T, _>(groups_slice, |[first, len]| {
                         debug_assert!(len <= self.len() as IdxSize);
                         match len {
                             0 => None,
                             1 => self.get(first as usize),
                             _ => {
-                                let arr_group = slice_from_offsets(self, first, len);
+                                let arr_group = _slice_from_offsets(self, first, len);
                                 arr_group.max()
                             }
                         }
@@ -519,7 +592,7 @@ where
 
     pub(crate) unsafe fn agg_sum(&self, groups: &GroupsProxy) -> Series {
         match groups {
-            GroupsProxy::Idx(groups) => agg_helper_idx::<T, _>(groups, |(first, idx)| {
+            GroupsProxy::Idx(groups) => _agg_helper_idx::<T, _>(groups, |(first, idx)| {
                 debug_assert!(idx.len() <= self.len());
                 if idx.is_empty() {
                     None
@@ -550,16 +623,16 @@ where
                 }
             }),
             GroupsProxy::Slice { groups, .. } => {
-                if use_rolling_kernels(groups, self.chunks()) {
+                if _use_rolling_kernels(groups, self.chunks()) {
                     let arr = self.downcast_iter().next().unwrap();
                     let values = arr.values().as_slice();
                     let offset_iter = groups.iter().map(|[first, len]| (*first, *len));
                     let arr = match arr.validity() {
-                        None => rolling_apply_agg_window_no_nulls::<SumWindow<_>, _, _>(
+                        None => _rolling_apply_agg_window_no_nulls::<SumWindow<_>, _, _>(
                             values,
                             offset_iter,
                         ),
-                        Some(validity) => rolling_apply_agg_window_nulls::<
+                        Some(validity) => _rolling_apply_agg_window_nulls::<
                             rolling::nulls::SumWindow<_>,
                             _,
                             _,
@@ -567,13 +640,13 @@ where
                     };
                     Self::from_chunks("", vec![arr]).into_series()
                 } else {
-                    agg_helper_slice::<T, _>(groups, |[first, len]| {
+                    _agg_helper_slice::<T, _>(groups, |[first, len]| {
                         debug_assert!(len <= self.len() as IdxSize);
                         match len {
                             0 => None,
                             1 => self.get(first as usize),
                             _ => {
-                                let arr_group = slice_from_offsets(self, first, len);
+                                let arr_group = _slice_from_offsets(self, first, len);
                                 arr_group.sum()
                             }
                         }
@@ -600,7 +673,7 @@ where
     pub(crate) unsafe fn agg_mean(&self, groups: &GroupsProxy) -> Series {
         match groups {
             GroupsProxy::Idx(groups) => {
-                agg_helper_idx::<T, _>(groups, |(first, idx)| {
+                _agg_helper_idx::<T, _>(groups, |(first, idx)| {
                     // this can fail due to a bug in lazy code.
                     // here users can create filters in aggregations
                     // and thereby creating shorter columns than the original group tuples.
@@ -647,16 +720,16 @@ where
                 })
             }
             GroupsProxy::Slice { groups, .. } => {
-                if use_rolling_kernels(groups, self.chunks()) {
+                if _use_rolling_kernels(groups, self.chunks()) {
                     let arr = self.downcast_iter().next().unwrap();
                     let values = arr.values().as_slice();
                     let offset_iter = groups.iter().map(|[first, len]| (*first, *len));
                     let arr = match arr.validity() {
-                        None => rolling_apply_agg_window_no_nulls::<MeanWindow<_>, _, _>(
+                        None => _rolling_apply_agg_window_no_nulls::<MeanWindow<_>, _, _>(
                             values,
                             offset_iter,
                         ),
-                        Some(validity) => rolling_apply_agg_window_nulls::<
+                        Some(validity) => _rolling_apply_agg_window_nulls::<
                             rolling::nulls::MeanWindow<_>,
                             _,
                             _,
@@ -664,13 +737,13 @@ where
                     };
                     ChunkedArray::<T>::from_chunks("", vec![arr]).into_series()
                 } else {
-                    agg_helper_slice::<T, _>(groups, |[first, len]| {
+                    _agg_helper_slice::<T, _>(groups, |[first, len]| {
                         debug_assert!(len <= self.len() as IdxSize);
                         match len {
                             0 => None,
                             1 => self.get(first as usize),
                             _ => {
-                                let arr_group = slice_from_offsets(self, first, len);
+                                let arr_group = _slice_from_offsets(self, first, len);
                                 arr_group.mean().map(|flt| NumCast::from(flt).unwrap())
                             }
                         }
@@ -692,16 +765,16 @@ where
                 take.var_as_series(ddof).unpack::<T>().unwrap().get(0)
             }),
             GroupsProxy::Slice { groups, .. } => {
-                if use_rolling_kernels(groups, self.chunks()) {
+                if _use_rolling_kernels(groups, self.chunks()) {
                     let arr = self.downcast_iter().next().unwrap();
                     let values = arr.values().as_slice();
                     let offset_iter = groups.iter().map(|[first, len]| (*first, *len));
                     let arr = match arr.validity() {
-                        None => rolling_apply_agg_window_no_nulls::<VarWindow<_>, _, _>(
+                        None => _rolling_apply_agg_window_no_nulls::<VarWindow<_>, _, _>(
                             values,
                             offset_iter,
                         ),
-                        Some(validity) => rolling_apply_agg_window_nulls::<
+                        Some(validity) => _rolling_apply_agg_window_nulls::<
                             rolling::nulls::VarWindow<_>,
                             _,
                             _,
@@ -709,13 +782,13 @@ where
                     };
                     ChunkedArray::<T>::from_chunks("", vec![arr]).into_series()
                 } else {
-                    agg_helper_slice::<T, _>(groups, |[first, len]| {
+                    _agg_helper_slice::<T, _>(groups, |[first, len]| {
                         debug_assert!(len <= self.len() as IdxSize);
                         match len {
                             0 => None,
                             1 => NumCast::from(0),
                             _ => {
-                                let arr_group = slice_from_offsets(self, first, len);
+                                let arr_group = _slice_from_offsets(self, first, len);
                                 arr_group.var(ddof).map(|flt| NumCast::from(flt).unwrap())
                             }
                         }
@@ -736,16 +809,16 @@ where
                 take.std_as_series(ddof).unpack::<T>().unwrap().get(0)
             }),
             GroupsProxy::Slice { groups, .. } => {
-                if use_rolling_kernels(groups, self.chunks()) {
+                if _use_rolling_kernels(groups, self.chunks()) {
                     let arr = self.downcast_iter().next().unwrap();
                     let values = arr.values().as_slice();
                     let offset_iter = groups.iter().map(|[first, len]| (*first, *len));
                     let arr = match arr.validity() {
-                        None => rolling_apply_agg_window_no_nulls::<StdWindow<_>, _, _>(
+                        None => _rolling_apply_agg_window_no_nulls::<StdWindow<_>, _, _>(
                             values,
                             offset_iter,
                         ),
-                        Some(validity) => rolling_apply_agg_window_nulls::<
+                        Some(validity) => _rolling_apply_agg_window_nulls::<
                             rolling::nulls::StdWindow<_>,
                             _,
                             _,
@@ -753,13 +826,13 @@ where
                     };
                     ChunkedArray::<T>::from_chunks("", vec![arr]).into_series()
                 } else {
-                    agg_helper_slice::<T, _>(groups, |[first, len]| {
+                    _agg_helper_slice::<T, _>(groups, |[first, len]| {
                         debug_assert!(len <= self.len() as IdxSize);
                         match len {
                             0 => None,
                             1 => NumCast::from(0),
                             _ => {
-                                let arr_group = slice_from_offsets(self, first, len);
+                                let arr_group = _slice_from_offsets(self, first, len);
                                 arr_group.std(ddof).map(|flt| NumCast::from(flt).unwrap())
                             }
                         }
@@ -791,7 +864,7 @@ where
                     .get(0)
             }),
             GroupsProxy::Slice { groups, .. } => {
-                if use_rolling_kernels(groups, self.chunks()) {
+                if _use_rolling_kernels(groups, self.chunks()) {
                     let arr = self.downcast_iter().next().unwrap();
                     let values = arr.values().as_slice();
                     let offset_iter = groups.iter().map(|[first, len]| (*first, *len));
@@ -812,13 +885,13 @@ where
                     };
                     ChunkedArray::<T>::from_chunks("", vec![arr]).into_series()
                 } else {
-                    agg_helper_slice::<T, _>(groups, |[first, len]| {
+                    _agg_helper_slice::<T, _>(groups, |[first, len]| {
                         debug_assert!(len <= self.len() as IdxSize);
                         match len {
                             0 => None,
                             1 => self.get(first as usize),
                             _ => {
-                                let arr_group = slice_from_offsets(self, first, len);
+                                let arr_group = _slice_from_offsets(self, first, len);
                                 // unwrap checked with invalid quantile check
                                 arr_group
                                     .quantile(quantile, interpol)
@@ -861,7 +934,7 @@ where
     pub(crate) unsafe fn agg_mean(&self, groups: &GroupsProxy) -> Series {
         match groups {
             GroupsProxy::Idx(groups) => {
-                agg_helper_idx::<Float64Type, _>(groups, |(first, idx)| {
+                _agg_helper_idx::<Float64Type, _>(groups, |(first, idx)| {
                     // this can fail due to a bug in lazy code.
                     // here users can create filters in aggregations
                     // and thereby creating shorter columns than the original group tuples.
@@ -915,17 +988,17 @@ where
                 groups: groups_slice,
                 ..
             } => {
-                if use_rolling_kernels(groups_slice, self.chunks()) {
+                if _use_rolling_kernels(groups_slice, self.chunks()) {
                     let ca = self.cast(&DataType::Float64).unwrap();
                     ca.agg_mean(groups)
                 } else {
-                    agg_helper_slice::<Float64Type, _>(groups_slice, |[first, len]| {
+                    _agg_helper_slice::<Float64Type, _>(groups_slice, |[first, len]| {
                         debug_assert!(len < self.len() as IdxSize);
                         match len {
                             0 => None,
                             1 => self.get(first as usize).map(|v| NumCast::from(v).unwrap()),
                             _ => {
-                                let arr_group = slice_from_offsets(self, first, len);
+                                let arr_group = _slice_from_offsets(self, first, len);
                                 arr_group.mean()
                             }
                         }
@@ -952,17 +1025,17 @@ where
                 groups: groups_slice,
                 ..
             } => {
-                if use_rolling_kernels(groups_slice, self.chunks()) {
+                if _use_rolling_kernels(groups_slice, self.chunks()) {
                     let ca = self.cast(&DataType::Float64).unwrap();
                     ca.agg_var(groups, ddof)
                 } else {
-                    agg_helper_slice::<Float64Type, _>(groups_slice, |[first, len]| {
+                    _agg_helper_slice::<Float64Type, _>(groups_slice, |[first, len]| {
                         debug_assert!(len <= self.len() as IdxSize);
                         match len {
                             0 => None,
                             1 => NumCast::from(0),
                             _ => {
-                                let arr_group = slice_from_offsets(self, first, len);
+                                let arr_group = _slice_from_offsets(self, first, len);
                                 arr_group.var(ddof)
                             }
                         }
@@ -988,17 +1061,17 @@ where
                 groups: groups_slice,
                 ..
             } => {
-                if use_rolling_kernels(groups_slice, self.chunks()) {
+                if _use_rolling_kernels(groups_slice, self.chunks()) {
                     let ca = self.cast(&DataType::Float64).unwrap();
                     ca.agg_std(groups, ddof)
                 } else {
-                    agg_helper_slice::<Float64Type, _>(groups_slice, |[first, len]| {
+                    _agg_helper_slice::<Float64Type, _>(groups_slice, |[first, len]| {
                         debug_assert!(len <= self.len() as IdxSize);
                         match len {
                             0 => None,
                             1 => NumCast::from(0),
                             _ => {
-                                let arr_group = slice_from_offsets(self, first, len);
+                                let arr_group = _slice_from_offsets(self, first, len);
                                 arr_group.std(ddof)
                             }
                         }
@@ -1031,17 +1104,17 @@ where
                 groups: groups_slice,
                 ..
             } => {
-                if use_rolling_kernels(groups_slice, self.chunks()) {
+                if _use_rolling_kernels(groups_slice, self.chunks()) {
                     let ca = self.cast(&DataType::Float64).unwrap();
                     ca.agg_quantile(groups, quantile, interpol)
                 } else {
-                    agg_helper_slice::<Float64Type, _>(groups_slice, |[first, len]| {
+                    _agg_helper_slice::<Float64Type, _>(groups_slice, |[first, len]| {
                         debug_assert!(len <= self.len() as IdxSize);
                         match len {
                             0 => None,
                             1 => self.get(first as usize).map(|v| NumCast::from(v).unwrap()),
                             _ => {
-                                let arr_group = slice_from_offsets(self, first, len);
+                                let arr_group = _slice_from_offsets(self, first, len);
                                 arr_group.quantile(quantile, interpol).unwrap()
                             }
                         }
@@ -1067,17 +1140,17 @@ where
                 groups: groups_slice,
                 ..
             } => {
-                if use_rolling_kernels(groups_slice, self.chunks()) {
+                if _use_rolling_kernels(groups_slice, self.chunks()) {
                     let ca = self.cast(&DataType::Float64).unwrap();
                     ca.agg_median(groups)
                 } else {
-                    agg_helper_slice::<Float64Type, _>(groups_slice, |[first, len]| {
+                    _agg_helper_slice::<Float64Type, _>(groups_slice, |[first, len]| {
                         debug_assert!(len <= self.len() as IdxSize);
                         match len {
                             0 => None,
                             1 => self.get(first as usize).map(|v| NumCast::from(v).unwrap()),
                             _ => {
-                                let arr_group = slice_from_offsets(self, first, len);
+                                let arr_group = _slice_from_offsets(self, first, len);
                                 arr_group.median()
                             }
                         }
