@@ -48,7 +48,7 @@ use crate::utils::series::to_physical_and_bit_repr;
 use crate::utils::{set_partition_size, slice_slice, split_ca};
 use crate::vector_hasher::{
     create_hash_and_keys_threaded_vectorized, prepare_hashed_relation_threaded, this_partition,
-    AsU64, StrHash,
+    AsU64, BytesHash,
 };
 use crate::POOL;
 
@@ -97,6 +97,8 @@ macro_rules! det_hash_prone_order {
 }
 
 pub(super) use det_hash_prone_order;
+#[cfg(feature = "performant")]
+use polars_arrow::conversion::primitive_to_vec;
 
 use crate::series::IsSorted;
 
@@ -355,12 +357,18 @@ impl DataFrame {
 
         #[cfg(feature = "chunked_ids")]
         {
-            if _check_rechunk {
+            // a left join create chunked-ids
+            // the others not yet.
+            // TODO! change this to other join types once they support chunked-id joins
+            if _check_rechunk
+                && !(matches!(how, JoinType::Left)
+                    || std::env::var("POLARS_NO_CHUNKED_JOIN").is_ok())
+            {
                 let mut left = Cow::Borrowed(self);
                 let mut right = Cow::Borrowed(other);
                 if self.should_rechunk() {
                     if _verbose {
-                        eprintln!("join triggered a rechunk of the left dataframe: {} columns are affected", self.width());
+                        eprintln!("{:?} join triggered a rechunk of the left dataframe: {} columns are affected", how, self.width());
                     }
 
                     let mut tmp_left = self.clone();
@@ -369,7 +377,7 @@ impl DataFrame {
                 }
                 if other.should_rechunk() {
                     if _verbose {
-                        eprintln!("join triggered a rechunk of the right dataframe: {} columns are affected", other.width());
+                        eprintln!("{:?} join triggered a rechunk of the right dataframe: {} columns are affected", how, other.width());
                     }
                     let mut tmp_right = other.clone();
                     tmp_right.as_single_chunk_par();
@@ -383,7 +391,7 @@ impl DataFrame {
                     suffix,
                     slice,
                     false,
-                    false,
+                    _verbose,
                 );
             }
         }
@@ -412,9 +420,11 @@ impl DataFrame {
             let s_right = other.column(selected_right[0].name())?;
             return match how {
                 JoinType::Inner => {
-                    self.inner_join_from_series(other, s_left, s_right, suffix, slice)
+                    self.inner_join_from_series(other, s_left, s_right, suffix, slice, _verbose)
+                }
+                JoinType::Left => {
+                    self.left_join_from_series(other, s_left, s_right, suffix, slice, _verbose)
                 }
-                JoinType::Left => self.left_join_from_series(other, s_left, s_right, suffix, slice),
                 JoinType::Outer => {
                     self.outer_join_from_series(other, s_left, s_right, suffix, slice)
                 }
@@ -672,22 +682,12 @@ impl DataFrame {
         s_right: &Series,
         suffix: Option<String>,
         slice: Option<(i64, usize)>,
+        verbose: bool,
     ) -> PolarsResult<DataFrame> {
         #[cfg(feature = "dtype-categorical")]
         check_categorical_src(s_left.dtype(), s_right.dtype())?;
-
-        let ((join_tuples_left, join_tuples_right), sorted) = if use_sort_merge(s_left, s_right) {
-            #[cfg(feature = "performant")]
-            {
-                (par_sorted_merge_inner(s_left, s_right), true)
-            }
-            #[cfg(not(feature = "performant"))]
-            {
-                s_left.hash_join_inner(s_right)
-            }
-        } else {
-            s_left.hash_join_inner(s_right)
-        };
+        let ((join_tuples_left, join_tuples_right), sorted) =
+            sort_or_hash_inner(s_left, s_right, verbose);
 
         let mut join_tuples_left = &*join_tuples_left;
         let mut join_tuples_right = &*join_tuples_right;
@@ -848,32 +848,11 @@ impl DataFrame {
         s_right: &Series,
         suffix: Option<String>,
         slice: Option<(i64, usize)>,
+        verbose: bool,
     ) -> PolarsResult<DataFrame> {
         #[cfg(feature = "dtype-categorical")]
         check_categorical_src(s_left.dtype(), s_right.dtype())?;
-
-        let ids = if use_sort_merge(s_left, s_right) {
-            #[cfg(feature = "performant")]
-            {
-                let (left_idx, right_idx) = par_sorted_merge_left(s_left, s_right);
-                #[cfg(feature = "chunked_ids")]
-                {
-                    (Either::Left(left_idx), Either::Left(right_idx))
-                }
-
-                #[cfg(not(feature = "chunked_ids"))]
-                {
-                    (left_idx, right_idx)
-                }
-            }
-            #[cfg(not(feature = "performant"))]
-            {
-                s_left.hash_join_left(s_right)
-            }
-        } else {
-            s_left.hash_join_left(s_right)
-        };
-
+        let ids = sort_or_hash_left(s_left, s_right, verbose);
         self.finish_left_join(ids, &other.drop(s_right.name()).unwrap(), suffix, slice)
     }
 
@@ -1003,6 +982,8 @@ impl DataFrame {
 mod test {
     use crate::df;
     use crate::prelude::*;
+    #[cfg(feature = "dtype-categorical")]
+    use crate::{reset_string_cache, IUseStringCache};
 
     fn create_frames() -> (DataFrame, DataFrame) {
         let s0 = Series::new("days", &[0, 1, 2]);
@@ -1198,14 +1179,12 @@ mod test {
             .join(&df_b, ["a", "b"], ["foo", "bar"], JoinType::Left, None)
             .unwrap();
         let ca = joined.column("ham").unwrap().utf8().unwrap();
-        dbg!(&df_a, &df_b);
         assert_eq!(Vec::from(ca), correct_ham);
         let joined_inner_hack = df_a.inner_join(&df_b, ["dummy"], ["dummy"]).unwrap();
         let joined_inner = df_a
             .join(&df_b, ["a", "b"], ["foo", "bar"], JoinType::Inner, None)
             .unwrap();
 
-        dbg!(&joined_inner_hack, &joined_inner);
         assert!(joined_inner_hack
             .column("ham")
             .unwrap()
@@ -1265,8 +1244,8 @@ mod test {
         df_a.try_apply("b", |s| s.cast(&DataType::Categorical(None)))
             .unwrap();
         // create a new cache
-        toggle_string_cache(false);
-        toggle_string_cache(true);
+        reset_string_cache();
+        let sc = IUseStringCache::new();
 
         df_b.try_apply("bar", |s| s.cast(&DataType::Categorical(None)))
             .unwrap();
