@@ -443,8 +443,8 @@ fn skip_this_line(bytes: &[u8], quote: Option<u8>, eol_char: u8) -> &[u8] {
 /// * `buffers` - Parsed output will be written to these buffers. Except for UTF8 data. The offsets of the
 ///               fields are written to the buffers. The UTF8 data will be parsed later.
 #[allow(clippy::too_many_arguments)]
-pub(super) fn parse_lines(
-    mut bytes: &[u8],
+pub(super) fn parse_lines<'a>(
+    mut bytes: &'a [u8],
     offset: usize,
     delimiter: u8,
     comment_char: Option<u8>,
@@ -452,7 +452,7 @@ pub(super) fn parse_lines(
     eol_char: u8,
     null_values: Option<&NullValuesCompiled>,
     projection: &[usize],
-    buffers: &mut [Buffer],
+    buffers: &mut [Buffer<'a>],
     ignore_parser_errors: bool,
     n_lines: usize,
     // length or original schema
