@@ -8,7 +8,7 @@ fn test_sorted_groupby() -> PolarsResult<()> {
     let mut s = Series::new("a", &[Some(1), Some(1), Some(1), Some(6), Some(6), None]);
     s.set_sorted(IsSorted::Ascending);
     for mt in [true, false] {
-        let out = s.group_tuples(mt, false);
+        let out = s.group_tuples(mt, false)?;
         assert_eq!(out.unwrap_slice(), &[[0, 3], [3, 2], [5, 1]]);
     }
 
@@ -19,7 +19,7 @@ fn test_sorted_groupby() -> PolarsResult<()> {
     );
     s.set_sorted(IsSorted::Ascending);
     for mt in [true, false] {
-        let out = s.group_tuples(mt, false);
+        let out = s.group_tuples(mt, false)?;
         assert_eq!(out.unwrap_slice(), &[[0, 2], [2, 3], [5, 2]]);
     }
 
@@ -27,7 +27,7 @@ fn test_sorted_groupby() -> PolarsResult<()> {
     let mut s = Series::new("a", &[Some(1), Some(1), Some(1), Some(6), Some(6), None]);
     s.set_sorted(IsSorted::Ascending);
     for mt in [true, false] {
-        let out = s.group_tuples(mt, false);
+        let out = s.group_tuples(mt, false)?;
         assert_eq!(out.unwrap_slice(), &[[0, 3], [3, 2], [5, 1]]);
     }
 
@@ -47,7 +47,7 @@ fn test_sorted_groupby() -> PolarsResult<()> {
     );
     s.set_sorted(IsSorted::Descending);
     for mt in [false, true] {
-        let out = s.group_tuples(mt, false);
+        let out = s.group_tuples(mt, false)?;
         assert_eq!(out.unwrap_slice(), &[[0, 2], [2, 2], [4, 3], [7, 1]]);
     }
 
@@ -76,7 +76,7 @@ fn test_sorted_groupby() -> PolarsResult<()> {
     );
     s.set_sorted(IsSorted::Descending);
     for mt in [false, true] {
-        let out = s.group_tuples(mt, false);
+        let out = s.group_tuples(mt, false)?;
         assert_eq!(
             out.unwrap_slice(),
             &[
