@@ -1,5 +1,3 @@
-use std::borrow::Cow;
-
 use polars::lazy::dsl;
 use polars::lazy::dsl::Operator;
 use polars::prelude::*;
@@ -138,6 +136,14 @@ impl PyExpr {
     pub fn max(&self) -> PyExpr {
         self.clone().inner.max().into()
     }
+    #[cfg(feature = "propagate_nans")]
+    pub fn nan_max(&self) -> PyExpr {
+        self.clone().inner.nan_max().into()
+    }
+    #[cfg(feature = "propagate_nans")]
+    pub fn nan_min(&self) -> PyExpr {
+        self.clone().inner.nan_min().into()
+    }
     pub fn mean(&self) -> PyExpr {
         self.clone().inner.mean().into()
     }
@@ -555,43 +561,16 @@ impl PyExpr {
             .into()
     }
 
-    pub fn str_strip(&self) -> PyExpr {
-        let function = |s: Series| {
-            let ca = s.utf8()?;
-
-            Ok(ca.apply(|s| Cow::Borrowed(s.trim())).into_series())
-        };
-        self.clone()
-            .inner
-            .map(function, GetOutput::same_type())
-            .with_fmt("str.strip")
-            .into()
+    pub fn str_strip(&self, matches: Option<char>) -> PyExpr {
+        self.inner.clone().str().strip(matches).into()
     }
 
-    pub fn str_rstrip(&self) -> PyExpr {
-        let function = |s: Series| {
-            let ca = s.utf8()?;
-
-            Ok(ca.apply(|s| Cow::Borrowed(s.trim_end())).into_series())
-        };
-        self.clone()
-            .inner
-            .map(function, GetOutput::same_type())
-            .with_fmt("str.rstrip")
-            .into()
+    pub fn str_rstrip(&self, matches: Option<char>) -> PyExpr {
+        self.inner.clone().str().rstrip(matches).into()
     }
 
-    pub fn str_lstrip(&self) -> PyExpr {
-        let function = |s: Series| {
-            let ca = s.utf8()?;
-
-            Ok(ca.apply(|s| Cow::Borrowed(s.trim_start())).into_series())
-        };
-        self.clone()
-            .inner
-            .map(function, GetOutput::same_type())
-            .with_fmt("str.lstrip")
-            .into()
+    pub fn str_lstrip(&self, matches: Option<char>) -> PyExpr {
+        self.inner.clone().str().lstrip(matches).into()
     }
 
     pub fn str_slice(&self, start: i64, length: Option<u64>) -> PyExpr {
@@ -721,7 +700,7 @@ impl PyExpr {
         };
         self.clone()
             .inner
-            .map(function, GetOutput::from_type(DataType::Boolean))
+            .map(function, GetOutput::from_type(DataType::Utf8))
             .with_fmt("str.json_path_match")
             .into()
     }
@@ -801,6 +780,12 @@ impl PyExpr {
     pub fn second(&self) -> PyExpr {
         self.clone().inner.dt().second().into()
     }
+    pub fn millisecond(&self) -> PyExpr {
+        self.clone().inner.dt().millisecond().into()
+    }
+    pub fn microsecond(&self) -> PyExpr {
+        self.clone().inner.dt().microsecond().into()
+    }
     pub fn nanosecond(&self) -> PyExpr {
         self.clone().inner.dt().nanosecond().into()
     }
@@ -901,6 +886,10 @@ impl PyExpr {
         self.inner.clone().dt().cast_time_unit(tu.0).into()
     }
 
+    pub fn dt_cast_time_zone(&self, tz: String) -> PyExpr {
+        self.inner.clone().dt().cast_time_zone(tz).into()
+    }
+
     pub fn rolling_apply(
         &self,
         py: Python,
@@ -1696,12 +1685,18 @@ pub fn lit(value: &PyAny, allow_object: bool) -> PyResult<PyExpr> {
         let val = value.extract::<bool>().unwrap();
         Ok(dsl::lit(val).into())
     } else if let Ok(int) = value.downcast::<PyInt>() {
-        let val = int.extract::<i64>().unwrap();
-
-        if val > 0 && val < i32::MAX as i64 || val < 0 && val > i32::MIN as i64 {
-            Ok(dsl::lit(val as i32).into())
-        } else {
-            Ok(dsl::lit(val).into())
+        match int.extract::<i64>() {
+            Ok(val) => {
+                if val > 0 && val < i32::MAX as i64 || val < 0 && val > i32::MIN as i64 {
+                    Ok(dsl::lit(val as i32).into())
+                } else {
+                    Ok(dsl::lit(val).into())
+                }
+            }
+            _ => {
+                let val = int.extract::<u64>().unwrap();
+                Ok(dsl::lit(val).into())
+            }
         }
     } else if let Ok(float) = value.downcast::<PyFloat>() {
         let val = float.extract::<f64>().unwrap();
