@@ -18,6 +18,8 @@ pub mod prelude;
 pub(crate) mod py_modules;
 pub mod series;
 mod set;
+#[cfg(feature = "polars-sql")]
+mod sql;
 pub mod utils;
 
 #[cfg(target_os = "linux")]
@@ -39,8 +41,8 @@ use pyo3::wrap_pyfunction;
 use crate::conversion::{get_df, get_lf, get_pyseq, get_series, Wrap};
 use crate::dataframe::PyDataFrame;
 use crate::error::{
-    ArrowErrorException, ComputeError, DuplicateError, NoDataError, NotFoundError, PyPolarsErr,
-    SchemaError,
+    ArrowErrorException, ComputeError, DuplicateError, InvalidOperationError, NoDataError,
+    NotFoundError, PyPolarsErr, SchemaError,
 };
 use crate::file::{get_either_file, EitherRustPythonFile};
 use crate::lazy::dataframe::{PyLazyFrame, PyLazyGroupBy};
@@ -153,8 +155,13 @@ fn pearson_corr(a: dsl::PyExpr, b: dsl::PyExpr, ddof: u8) -> dsl::PyExpr {
 }
 
 #[pyfunction]
-fn spearman_rank_corr(a: dsl::PyExpr, b: dsl::PyExpr, ddof: u8) -> dsl::PyExpr {
-    polars::lazy::dsl::spearman_rank_corr(a.inner, b.inner, ddof).into()
+fn spearman_rank_corr(
+    a: dsl::PyExpr,
+    b: dsl::PyExpr,
+    ddof: u8,
+    propagate_nans: bool,
+) -> dsl::PyExpr {
+    polars::lazy::dsl::spearman_rank_corr(a.inner, b.inner, ddof, propagate_nans).into()
 }
 
 #[pyfunction]
@@ -212,12 +219,12 @@ fn py_datetime(
     hour: Option<dsl::PyExpr>,
     minute: Option<dsl::PyExpr>,
     second: Option<dsl::PyExpr>,
-    millisecond: Option<dsl::PyExpr>,
+    microsecond: Option<dsl::PyExpr>,
 ) -> dsl::PyExpr {
     let hour = hour.map(|e| e.inner);
     let minute = minute.map(|e| e.inner);
     let second = second.map(|e| e.inner);
-    let millisecond = millisecond.map(|e| e.inner);
+    let microsecond = microsecond.map(|e| e.inner);
 
     let args = DatetimeArgs {
         year: year.inner,
@@ -226,17 +233,19 @@ fn py_datetime(
         hour,
         minute,
         second,
-        millisecond,
+        microsecond,
     };
 
     polars::lazy::dsl::datetime(args).into()
 }
 
+#[allow(clippy::too_many_arguments)]
 #[pyfunction]
 fn py_duration(
     days: Option<PyExpr>,
     seconds: Option<PyExpr>,
     nanoseconds: Option<PyExpr>,
+    microseconds: Option<PyExpr>,
     milliseconds: Option<PyExpr>,
     minutes: Option<PyExpr>,
     hours: Option<PyExpr>,
@@ -246,6 +255,7 @@ fn py_duration(
         days: days.map(|e| e.inner),
         seconds: seconds.map(|e| e.inner),
         nanoseconds: nanoseconds.map(|e| e.inner),
+        microseconds: microseconds.map(|e| e.inner),
         milliseconds: milliseconds.map(|e| e.inner),
         minutes: minutes.map(|e| e.inner),
         hours: hours.map(|e| e.inner),
@@ -454,6 +464,12 @@ fn max_exprs(exprs: Vec<PyExpr>) -> PyExpr {
     polars::lazy::dsl::max_exprs(exprs).into()
 }
 
+#[pyfunction]
+fn coalesce_exprs(exprs: Vec<PyExpr>) -> PyExpr {
+    let exprs = exprs.to_exprs();
+    polars::lazy::dsl::coalesce(&exprs).into()
+}
+
 #[pyfunction]
 fn sum_exprs(exprs: Vec<PyExpr>) -> PyExpr {
     let exprs = exprs.to_exprs();
@@ -497,11 +513,18 @@ fn polars(py: Python, m: &PyModule) -> PyResult<()> {
         .unwrap();
     m.add("PanicException", py.get_type::<PanicException>())
         .unwrap();
+    m.add(
+        "InvalidOperationError",
+        py.get_type::<InvalidOperationError>(),
+    )
+    .unwrap();
     m.add_class::<PySeries>().unwrap();
     m.add_class::<PyDataFrame>().unwrap();
     m.add_class::<PyLazyFrame>().unwrap();
     m.add_class::<PyLazyGroupBy>().unwrap();
     m.add_class::<dsl::PyExpr>().unwrap();
+    #[cfg(feature = "polars-sql")]
+    m.add_class::<sql::PySQLContext>().unwrap();
     m.add_wrapped(wrap_pyfunction!(col)).unwrap();
     m.add_wrapped(wrap_pyfunction!(count)).unwrap();
     m.add_wrapped(wrap_pyfunction!(first)).unwrap();
@@ -546,5 +569,6 @@ fn polars(py: Python, m: &PyModule) -> PyResult<()> {
     m.add_wrapped(wrap_pyfunction!(pool_size)).unwrap();
     m.add_wrapped(wrap_pyfunction!(arg_where)).unwrap();
     m.add_wrapped(wrap_pyfunction!(get_idx_type)).unwrap();
+    m.add_wrapped(wrap_pyfunction!(coalesce_exprs)).unwrap();
     Ok(())
 }
