@@ -3,7 +3,7 @@ from __future__ import annotations
 import io
 import sys
 from datetime import date, datetime, time, timedelta
-from typing import TYPE_CHECKING, no_type_check
+from typing import TYPE_CHECKING, cast, no_type_check
 
 import numpy as np
 import pandas as pd
@@ -264,16 +264,19 @@ def test_datetime_consistency() -> None:
 def test_timezone() -> None:
     ts = pa.timestamp("s")
     data = pa.array([1000, 2000], type=ts)
-    s: pl.Series = pl.from_arrow(data)  # type: ignore[assignment]
+    s = cast(pl.Series, pl.from_arrow(data))
 
     # with timezone; we do expect a warning here
     tz_ts = pa.timestamp("s", tz="America/New_York")
     tz_data = pa.array([1000, 2000], type=tz_ts)
     # with pytest.warns(Warning):
-    tz_s: pl.Series = pl.from_arrow(tz_data)  # type: ignore[assignment]
+    tz_s = cast(pl.Series, pl.from_arrow(tz_data))
 
-    # timezones have no effect, i.e. `s` equals `tz_s`
-    assert not s.series_equal(tz_s)
+    # different timezones are not considered equal
+    # we check both `null_equal=True` and `null_equal=False`
+    # https://github.com/pola-rs/polars/issues/5023
+    assert not s.series_equal(tz_s, null_equal=False)
+    assert not s.series_equal(tz_s, null_equal=True)
     assert s.cast(int).series_equal(tz_s.cast(int))
 
 
@@ -645,8 +648,8 @@ def test_microseconds_accuracy() -> None:
             ]
         ),
     )
-
-    assert pl.from_arrow(a)["timestamp"].to_list() == timestamps
+    df = cast(pl.DataFrame, pl.from_arrow(a))
+    assert df["timestamp"].to_list() == timestamps
 
 
 def test_cast_time_units() -> None:
@@ -674,8 +677,7 @@ def test_read_utc_times_parquet() -> None:
     df.to_parquet(f)
     f.seek(0)
     df_in = pl.read_parquet(f)
-    tz = zoneinfo.ZoneInfo("UTC")
-    assert df_in["Timestamp"][0] == datetime(2022, 1, 1, 0, 0).astimezone(tz)
+    assert df_in["Timestamp"][0] == datetime(2022, 1, 1, 0, 0)
 
 
 def test_epoch() -> None:
@@ -1514,8 +1516,8 @@ def test_short_formats() -> None:
 
 
 def test_iso_year() -> None:
-    dt = datetime(2022, 1, 1, 7, 8, 40)
-    assert pl.Series([dt]).dt.iso_year()[0] == 2021
+    assert pl.Series([datetime(2022, 1, 1, 7, 8, 40)]).dt.iso_year()[0] == 2021
+    assert pl.Series([date(2022, 1, 1)]).dt.iso_year()[0] == 2021
 
 
 def test_invalid_date_parsing_4898() -> None:
@@ -1534,3 +1536,20 @@ def test_cast_timezone() -> None:
         "a": [datetime(2022, 9, 25, 14, 0)],
         "b": [datetime(2022, 9, 25, 18, 0)],
     }
+    assert pl.DataFrame({"a": [datetime(2022, 9, 25, 18)]}).with_column(
+        pl.col("a")
+        .dt.with_time_zone("UTC")
+        .dt.cast_time_zone("America/New_York")
+        .alias("b")
+    ).to_dict(False) == {
+        "a": [datetime(2022, 9, 25, 18, 0)],
+        "b": [datetime(2022, 9, 25, 14, 0)],
+    }
+
+
+def test_tz_aware_get_idx_5010() -> None:
+    when = int(
+        datetime(2022, 1, 1, 12, tzinfo=zoneinfo.ZoneInfo("Asia/Shanghai")).timestamp()
+    )
+    a = pa.array([when]).cast(pa.timestamp("s", tz="Asia/Shanghai"))
+    assert int(pl.from_arrow(a)[0].timestamp()) == when  # type: ignore[union-attr]
