@@ -182,3 +182,16 @@ def test_error_on_double_agg() -> None:
                 .groupby("a")
                 .agg([getattr(pl.col("b").min(), e)()])
             )
+
+
+def test_unique_on_list_df() -> None:
+    with pytest.raises(pl.InvalidOperationError):
+        pl.DataFrame({"a": [1, 2, 3, 4], "b": [[1, 1], [2], [3], [4, 4]]}).unique()
+
+
+def test_filter_not_of_type_bool() -> None:
+    df = pl.DataFrame({"json_val": ['{"a":"hello"}', None, '{"a":"world"}']})
+    with pytest.raises(
+        pl.ComputeError, match="Filter predicate must be of type Boolean, got"
+    ):
+        df.filter(pl.col("json_val").str.json_path_match("$.a"))
